@@ -163,7 +163,8 @@ def transform(image: tf.Tensor, transforms) -> tf.Tensor:
     if transforms.shape.rank == 1:
         transforms = transforms[None]
     image = to_4d(image)
-    image = image_ops.transform(images=image, transforms=transforms, interpolation="nearest", fill_mode="constant")
+    # image = image_ops.transform(images=image, transforms=transforms, interpolation="nearest", fill_mode="constant")
+    image = image_ops.transform(images=image, transforms=transforms, interpolation="bilinear", fill_mode="constant")
     return from_4d(image, original_ndims)
 
 
@@ -1018,7 +1019,7 @@ class RandAugment(ImageAugment):
         return func(image, *args)
 
     def select_and_apply_random_policy(self, image):
-        """Select a random policy from `policies` and apply it to `image`."""
+        """ Select a random policy from `policies` and apply it to `image`. """
         policy_to_select = tf.random.uniform([], maxval=len(self.available_ops), dtype=tf.int32)
         branch_fns = [(id, lambda selected=ii: self.apply_policy(selected, image)) for id, ii in enumerate(self.available_ops)]
         image = tf.switch_case(branch_index=policy_to_select, branch_fns=branch_fns, default=lambda: tf.identity(image))
