@@ -48,6 +48,7 @@ def __deprocess_image__(img):
     img = np.clip(img, 0, 255).astype("uint8")
     return img
 
+
 def __get_cols_rows__(total, rows=-1):
     if rows == -1 and total < 8:
         rows = 1  # for total in [1, 7], plot 1 row only
@@ -60,6 +61,7 @@ def __get_cols_rows__(total, rows=-1):
     cols = total // rows
     return cols, rows
 
+
 def stack_and_plot_images(images, margin=5, margin_value=0, rows=-1, ax=None, base_size=3):
     """ Stack and plot a list of images. Returns ax, stacked_images """
     import matplotlib.pyplot as plt
@@ -83,7 +85,7 @@ def stack_and_plot_images(images, margin=5, margin_value=0, rows=-1, ax=None, ba
 
         stacked_images = vstacked_images[:-margin, :-margin]
     else:
-        stacked_images = np.vstack([np.hstack(images[ii * cols: (rr + 1) * cols]) for ii in range(rows)])
+        stacked_images = np.vstack([np.hstack(images[ii * cols : (rr + 1) * cols]) for ii in range(rows)])
 
     ax.imshow(stacked_images)
     ax.set_axis_off()
@@ -134,7 +136,7 @@ def make_gradcam_heatmap(model, img_array, layer_name, pred_index=None):
 
     # This is a vector where each entry is the mean intensity of the gradient
     # over a specific feature map channel
-    pooled_grads = tf.reduce_mean(grads, axis=list(range(0, len(grads.shape)-1)))
+    pooled_grads = tf.reduce_mean(grads, axis=list(range(0, len(grads.shape) - 1)))
 
     # We multiply each channel in the feature map array
     # by "how important this channel is" with regard to the top predicted class
@@ -277,7 +279,7 @@ def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto",
         # halo attn_score [batch, num_heads, hh, ww, query_block * query_block, kv_kernel * kv_kernel]
         print(">>>> Attention type: halo")
         from einops import rearrange
-        from keras_cv_attention_models.attention_layers import tpu_compatible_extract_patches
+        from keras_cv_attention_models.attention_layers import CompatibleExtractPatches
 
         mask = [np.array(ii)[0].mean(0) for ii in attn_scores if len(ii.shape) == 6][::-1]
 
@@ -286,7 +288,7 @@ def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto",
         hhs = [(jj - ii) // 2 for ii, jj in zip(qqs, vvs)]  # halo_size
         tt = [rearrange(ii, "hh ww (hb wb) cc -> (hh hb) (ww wb) cc", hb=qq, wb=qq) for ii, qq in zip(mask, qqs)]
         tt = [tf.expand_dims(tf.pad(ii, [[hh, hh], [hh, hh], [0, 0]]), 0) for ii, hh in zip(tt, hhs)]
-        tt = [tpu_compatible_extract_patches(ii, vv, qq, padding="VALID", compressed=False).numpy()[0] for ii, vv, qq in zip(tt, vvs, qqs)]
+        tt = [CompatibleExtractPatches(vv, qq, padding="VALID", compressed=False)(ii).numpy()[0] for ii, vv, qq in zip(tt, vvs, qqs)]
         tt = [rearrange(ii, "hh ww hb wb cc -> hh ww (hb wb) cc").mean((0, 1)) for ii in tt]
         # tt = [tf.reduce_max(rearrange(ii, "hh ww hb wb cc -> hh ww (hb wb) cc"), axis=(0, 1)).numpy() for ii in tt]
         cum_mask = [matmul_prod(tt[: ii + 1]).mean(0) for ii in range(len(tt))]
